# py-maidr

Python binder for maidr library

## Install and Upgrade

``` sh
# install the latest release from PyPI
pip install -U maidr

# or install the development version from GitHub
pip install -U git+https://github.com/xability/py_maidr.git
```
